# swarmauri/core/chunkers/__init__.py

from abc import ABC, abstractmethod
from typing import List, Union, Any

class IChunker(ABC):
    """
    Interface for chunking text into smaller pieces.

    This interface defines abstract methods for chunking texts. Implementing classes
    should provide concrete implementations for these methods tailored to their specific
    chunking algorithms.

    """
    
    @abstractmethod
    def chunk_text(self, text: Union[str, Any], *args, **kwargs) -> List[Any]:
        """
        Abstract method that splits a text into chunks.

        Parameters:
        - text (Union[str, Any]): The input text to be chunked. This can be a string 
                                  or any other format that the concrete implementation
                                  can handle.
        - *args: Variable length argument list. Allows for flexibility in arguments that
                 can be passed to implementing methods.
        - **kwargs: Arbitrary keyword arguments.
        
        Returns:
        - List[str]: A list of text chunks.
        """
        pass


from abc import ABC
from typing import List, Any
from swarmauri.core.documents.IEmbed import IEmbed


class EmbeddedBase(IEmbed, ABC):
    def __init__(self, embedding):
        self._embedding = embedding
            
    @property
    def embedding(self) -> List[Any]:
        """
        Get the document's ID.
        """
        return self._embedding

    @embedding.setter
    def embedding(self, value: List[Any]) -> None:
        """
        Set the document's ID.
        """
        self._embedding = value


from abc import ABC, abstractmethod
from typing import Dict

class IEmbed(ABC):
    @abstractmethod
    def __init__(self, doc_id, content, metadata: Dict):
        pass

    @property
    @abstractmethod
    def embedding(self) -> str:
        """
        Get the document's ID.
        """
        pass

    @embedding.setter
    @abstractmethod
    def embedding(self, value: str) -> None:
        """
        Set the document's ID.
        """
        pass

